@@ -13,7 +13,6 @@
 #'          the preceeding group. This may be necessary if cutting a vector into
 #'          groups does not define proper ("equal sized") group sizes.
 #'          See 'Note' and 'Examples'.
-#' @param groupcount Deprecated. Use \code{n} instead.
 #'
 #' @inheritParams to_factor
 #' @inheritParams group_var
@@ -88,91 +87,28 @@
 #'
 #' @importFrom stats quantile
 #' @export
-split_var <- function(x, ..., n, as.num = FALSE, val.labels = NULL, var.label = NULL, inclusive = FALSE, append = FALSE, suffix = "_g", groupcount) {
-
-  # check deprecated arguments
-  if (!missing(groupcount)) {
-    message("Argument `groupcount` is deprecated. Please use `n` instead.")
-    n <- groupcount
-  }
+split_var <- function(x, ..., n, as.num = FALSE, val.labels = NULL, var.label = NULL, inclusive = FALSE, append = FALSE, suffix = "_g") {
 
   # evaluate arguments, generate data
   .dat <- get_dot_data(x, dplyr::quos(...))
 
-  if (is.data.frame(x)) {
-    # remember original data, if user wants to bind columns
-    orix <- tibble::as_tibble(x)
-
-    # do we have a grouped data frame?
-    if (inherits(.dat, "grouped_df")) {
-
-      # get grouped data, as nested data frame
-      grps <- get_grouped_data(.dat)
-
-      # iterate all groups
-      for (i in seq_len(nrow(grps))) {
-        # get data from each single group
-        group <- grps$data[[i]]
-
-        # now iterate all variables of interest
-        for (j in colnames(group)) {
-          group[[j]] <- split_var_helper(
-            x = group[[j]],
-            groupcount = n,
-            as.num = as.num,
-            var.label = var.label,
-            val.labels = val.labels,
-            inclusive = inclusive
-          )
-        }
-
-        # write back data
-        grps$data[[i]] <- group
-      }
-
-      # unnest data frame
-      x <- tidyr::unnest(grps)
-
-      # remove grouping column
-      .dat <- .dat[colnames(.dat) %nin% dplyr::group_vars(.dat)]
-
-    } else {
-      # iterate variables of data frame
-      for (i in colnames(.dat)) {
-        x[[i]] <- split_var_helper(
-          x = .dat[[i]],
-          groupcount = n,
-          as.num = as.num,
-          var.label = var.label,
-          val.labels = val.labels,
-          inclusive = inclusive
-        )
-      }
-    }
-    # coerce to tibble and select only recoded variables
-    x <- tibble::as_tibble(x[colnames(.dat)])
-
-    # add suffix to recoded variables?
-    if (!is.null(suffix) && !sjmisc::is_empty(suffix)) {
-      colnames(x) <- sprintf("%s%s", colnames(x), suffix)
-    }
-
-    # combine data
-    if (append) x <- dplyr::bind_cols(orix, x)
-  } else {
-    x <- split_var_helper(
-      x = .dat,
-      groupcount = n,
-      as.num = as.num,
-      var.label = var.label,
-      val.labels = val.labels,
-      inclusive = inclusive
-    )
-  }
-
-  x
+  recode_fun(
+    x = x,
+    .dat = .dat,
+    fun = get("split_var_helper", asNamespace("sjmisc")),
+    suffix = suffix,
+    append = append,
+    groupcount = n,
+    as.num = as.num,
+    var.label = var.label,
+    val.labels = val.labels,
+    inclusive = inclusive
+  )
 }
 
+
+#' @importFrom stats quantile
+#' @importFrom sjlabelled get_label set_label set_labels
 split_var_helper <- function(x, groupcount, as.num, val.labels, var.label, inclusive) {
   # retrieve variable label
   if (is.null(var.label))
