@@ -18,11 +18,11 @@ library(dplyr)
 ## ----collapse=TRUE-------------------------------------------------------
 # select all variables with "cop" in their names, and also
 # the range from c161sex to c175empl
-rec(efc, ~contains("cop"), c161sex:c175empl, rec = "0,1=0; else=1")
+rec(efc, contains("cop"), c161sex:c175empl, rec = "0,1=0; else=1")
 
 # center all variables with "age" in name, variable c12hour
 # and all variables from column 19 to 21
-center(efc, c12hour, ~contains("age"), 19:21)
+center(efc, c12hour, contains("age"), 19:21)
 
 ## ------------------------------------------------------------------------
 to_factor(efc, e42dep, e16sex)
